@@ -60,7 +60,23 @@ class Role(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Role.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                name: builtins.str,
+                privileges: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[RolePrivileges, typing.Dict[str, typing.Any]]]],
+                description: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = RoleConfig(
@@ -87,7 +103,11 @@ class Role(
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Role.put_privileges)
+            def stub(
+                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[RolePrivileges, typing.Dict[str, typing.Any]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putPrivileges", [value]))
 
@@ -154,7 +174,9 @@ class Role(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Role, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -166,7 +188,9 @@ class Role(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Role, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -217,7 +241,21 @@ class RoleConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(RoleConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                name: builtins.str,
+                privileges: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[RolePrivileges, typing.Dict[str, typing.Any]]]],
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -369,7 +407,9 @@ class RolePrivileges:
         :param service_id: The obfuscated ID of the service this privilege is for. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/role#service_id Role#service_id}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RolePrivileges.__init__)
+            def stub(*, privilege_name: builtins.str, service_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument privilege_name", value=privilege_name, expected_type=type_hints["privilege_name"])
             check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -426,7 +466,13 @@ class RolePrivilegesList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RolePrivilegesList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -438,7 +484,9 @@ class RolePrivilegesList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RolePrivilegesList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("RolePrivilegesOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -451,7 +499,9 @@ class RolePrivilegesList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RolePrivilegesList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -464,7 +514,9 @@ class RolePrivilegesList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RolePrivilegesList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -477,7 +529,9 @@ class RolePrivilegesList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RolePrivilegesList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -494,7 +548,11 @@ class RolePrivilegesList(
         value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[RolePrivileges]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RolePrivilegesList, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[RolePrivileges]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -518,7 +576,14 @@ class RolePrivilegesOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RolePrivilegesOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -543,7 +608,9 @@ class RolePrivilegesOutputReference(
     @privilege_name.setter
     def privilege_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RolePrivilegesOutputReference, "privilege_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "privilegeName", value)
 
@@ -555,7 +622,9 @@ class RolePrivilegesOutputReference(
     @service_id.setter
     def service_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RolePrivilegesOutputReference, "service_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "serviceId", value)
 
@@ -572,7 +641,11 @@ class RolePrivilegesOutputReference(
         value: typing.Optional[typing.Union[RolePrivileges, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RolePrivilegesOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[RolePrivileges, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
